@@ -31,13 +31,6 @@ class Document:
     FACT_NAME_PHONE_HIGH_RECALL = "PHONE_high_recall"
     FACT_NAME_PHONE_HIGH_PRECISION = "PHONE_high_precision"
     FACT_NAME_PHONE_STRICT = "PHONE_strict"
-    FACT_NAMES_NER = ("PER", "ORG", "GPE", "LOC")
-    FACT_NAME_NAMEMAIL = "NAMEMAIL"
-    FACT_NAME_BOUNDED = "BOUNDED"
-
-    KNOWN_ENTITIES = (FACT_NAME_EMAIL, FACT_NAME_ADDRESS, FACT_NAME_PHONE_STRICT, FACT_NAME_NAMEMAIL) + FACT_NAMES_NER
-
-    CLOSE_FACT_DISTANCE = 150
 
 
     def __init__(
@@ -489,33 +482,30 @@ class Document:
 
     def ner(self):
         tokenized_text = self.get_words()
-        known_entities = Document.FACT_NAMES_NER
-
         for entity in self.stanza_entities:
-            if entity.type in known_entities:
-                # finds the closest spans in tokenized text
-                # this is because stanza returns spans from non-tokenized text
-                pattern = re.compile(re.escape(entity.text))  # Use re.escape to avoid trouble with special characters existing in the text.
-                matching_tokenized_spans = [(match.start(), match.end()) for match in pattern.finditer(tokenized_text)]
-                best_matching_span = None
-                best_matching_distance = math.inf
-                non_tokenized_span = (entity.start_char, entity.end_char)
-                # matching spans are always equal or larger
-                for span in matching_tokenized_spans:
-                    span_distance = (span[0] - non_tokenized_span[0]) + (span[1] - non_tokenized_span[1])
-                    if abs(span_distance) < best_matching_distance:
-                        best_matching_distance = abs(span_distance)
-                        best_matching_span = span
-                # create and append fact
-                # ignore facts whose match fails
-                if best_matching_span:
-                    text_before_match = tokenized_text[:best_matching_span[0]]
-                    sentence_index = text_before_match.count("\n")
-                    new_fact = Fact(
-                        fact_type=entity.type,
-                        fact_value=entity.text,
-                        doc_path=self.__get_doc_path("text"),
-                        spans=[best_matching_span],
-                        sent_index=sentence_index
-                    )
-                    self.__texta_facts.append(new_fact)
+            # finds the closest spans in tokenized text
+            # this is because stanza returns spans from non-tokenized text
+            pattern = re.compile(re.escape(entity.text))  # Use re.escape to avoid trouble with special characters existing in the text.
+            matching_tokenized_spans = [(match.start(), match.end()) for match in pattern.finditer(tokenized_text)]
+            best_matching_span = None
+            best_matching_distance = math.inf
+            non_tokenized_span = (entity.start_char, entity.end_char)
+            # matching spans are always equal or larger
+            for span in matching_tokenized_spans:
+                span_distance = (span[0] - non_tokenized_span[0]) + (span[1] - non_tokenized_span[1])
+                if abs(span_distance) < best_matching_distance:
+                    best_matching_distance = abs(span_distance)
+                    best_matching_span = span
+            # create and append fact
+            # ignore facts whose match fails
+            if best_matching_span:
+                text_before_match = tokenized_text[:best_matching_span[0]]
+                sentence_index = text_before_match.count("\n")
+                new_fact = Fact(
+                    fact_type=entity.type,
+                    fact_value=entity.text,
+                    doc_path=self.__get_doc_path("text"),
+                    spans=[best_matching_span],
+                    sent_index=sentence_index
+                )
+                self.__texta_facts.append(new_fact)
