@@ -9,3 +9,7 @@ class BoundedListEmpty(Exception):
 class StanzaPipelineFail(Exception):
     """Raised when Stanza pipelines fail to load."""
     pass
+
+class CUDAException(Exception):
+    """Raised when problems with CUDA settings or support."""
+    pass
