@@ -24,7 +24,8 @@ from texta_mlp.settings import (
     STANZA_NER_SUPPORT,
     SUPPORTED_ANALYZERS,
     DEFAULT_ANALYZERS,
-    ENTITY_MAPPER_DATA_URLS
+    ENTITY_MAPPER_DATA_URLS,
+    USE_GPU
 )
 
 
@@ -38,7 +39,7 @@ class MLP:
             resource_dir: str = DEFAULT_RESOURCE_DIR,
             ner_model_langs: list = CUSTOM_NER_MODEL_LANGS,
             logging_level: str ="error",
-            use_gpu: bool = True,
+            use_gpu: bool = USE_GPU,
             gpu_device_id: int = 0,
             refresh_data: bool = REFRESH_DATA
     ):
@@ -393,43 +394,3 @@ class MLP:
                         docs[actual_index] = result
 
         return docs
-
-
-    @staticmethod
-    def download_concatenator_resources(resource_dir: str, logger):
-        concat_resource_dir = pathlib.Path(resource_dir) / "concatenator"
-        concat_resource_dir.mkdir(parents=True, exist_ok=True)
-        for url in CONCATENATOR_DATA_FILES:
-            file_name = urlparse(url).path.split("/")[-1]
-            file_path = concat_resource_dir / file_name
-            if not file_path.exists():
-                if logger: logger.info(f"Downloading concatenator file {file_name} into the directory: {url}")
-                response = urlopen(url)
-                content = response.read().decode()
-                with open(file_path, "w", encoding="utf8") as fh:
-                    fh.write(content)
-
-
-    def _load_not_entities(self):
-        not_entities = list()
-        with open(self.not_entities_path, "r", encoding="UTF-8") as file:
-            for line in file.readlines():
-                not_entities += [line.strip().lower()]
-        return not_entities
-
-
-    def _load_space_between_not_ok(self):
-        space_between_not_ok = list()
-        with open(self.space_between_not_ok_path, "r", encoding="UTF-8") as file:
-            for line in file.readlines():
-                space_between_not_ok += [line.strip()]
-
-        return re.compile("|".join(space_between_not_ok))
-
-
-    def _load_months(self):
-        months = list()
-        with open(self.months_path, "r", encoding="UTF-8") as file:
-            for line in file.readlines():
-                months += [line.strip()]
-        return months
